import { Controller, Post, Body, InternalServerErrorException, HttpCode, Req } from '@nestjs/common';
import { ContactForm, EmailWithoutFrom, FeedbackForm } from './email';
import { EmailService } from './email.service';
import { ApiBadRequestResponse, ApiOkResponse, ApiOperation, ApiInternalServerErrorResponse } from '@nestjs/swagger';
import { Groups } from '../decorators/groups.decorators';
import { handleError } from '../helpers';

@Controller()
export class EmailController {

  constructor(
    private emailService: EmailService,
  ) { }

  @Post('contact')
  // tslint:disable-next-line:max-line-length
  @ApiOperation({ title: 'Send email to admin (emails defined as var env of the project, see docker-compose.yml file) and recap email to user email.' })
  @ApiOkResponse({ description: 'OK' })
  @ApiBadRequestResponse({ description: 'Missing fields' })
  @ApiInternalServerErrorResponse({ description: 'Internal error (unreachable SMTP server...)' })
  @HttpCode(200)
  async create(@Body() contactForm: ContactForm) {
    try {
      return await this.emailService.sendContactEmails(contactForm);
    } catch (error) {
      handleError(error, new InternalServerErrorException());
    }
  }

  @Post('feedback')
  // tslint:disable-next-line:max-line-length
  @ApiOperation({ title: 'Send email to admin with the user feedback' })
  @ApiOkResponse({ description: 'OK' })
  @ApiBadRequestResponse({ description: 'Missing fields' })
  @ApiInternalServerErrorResponse({ description: 'Internal error (unreachable SMTP server...)' })
  @HttpCode(200)
  async sendFeedback(@Body() feedbackForm: FeedbackForm, @Req() req) {
    try {
      return await this.emailService.sendFeedback(feedbackForm, req.headers['user-agent']);
    } catch (error) {
      handleError(error, new InternalServerErrorException());
    }
  }

  @Post('send')
  @Groups('emailWriter')
  @ApiOperation({ title: 'Send email.' })
  @ApiOkResponse({ description: 'OK' })
  @ApiBadRequestResponse({ description: 'Missing fields' })
  @ApiInternalServerErrorResponse({ description: 'Internal error (unreachable SMTP server...)' })
  @HttpCode(200)
  async createEmail(@Body() email: EmailWithoutFrom) {
    try {
      return await this.emailService.send(email);
    } catch (error) {
      handleError(error, new InternalServerErrorException());
    }
  }
}
