import { IsDefined, Length, IsEmail, IsString, IsNumber } from 'class-validator';
import { ApiModelProperty, ApiModelPropertyOptional } from '@nestjs/swagger';

export class ContactForm {

  @ApiModelProperty()
  @IsDefined()
  @IsEmail()
  email: string;

  @ApiModelProperty()
  @IsDefined()
  subject: string;

  @ApiModelProperty()
  @IsDefined()
  @Length(1)
  firstname: string;

  @ApiModelProperty()
  @IsDefined()
  @Length(1)
  lastname: string;

  @ApiModelProperty()
  @IsDefined()
  text: string;
}

export class Email {

  @ApiModelProperty()
  @IsDefined()
  to: string[];

  @ApiModelProperty()
  @IsDefined()
  from: string;

  @ApiModelPropertyOptional()
  replyTo: string;

  @ApiModelPropertyOptional()
  cc: string[];

  @ApiModelPropertyOptional()
  bcc: string[];

  @ApiModelProperty()
  @IsDefined()
  subject: string;

  @ApiModelProperty()
  @IsDefined()
  html: string;

}

export class EmailWithoutFrom {

  @ApiModelProperty()
  @IsDefined()
  to: string[];

  @ApiModelPropertyOptional()
  replyTo: string;

  @ApiModelPropertyOptional()
  cc: string[];

  @ApiModelPropertyOptional()
  bcc: string[];

  @ApiModelProperty()
  @IsDefined()
  subject: string;

  @ApiModelProperty()
  @IsDefined()
  html: string;

}

export class FeedbackForm {
  @ApiModelProperty()
  @IsDefined()
  url: string;

  @ApiModelProperty()
  @IsDefined()
  version: string;

  @ApiModelProperty()
  @IsDefined()
  message: string;

  @ApiModelPropertyOptional()
  email?: string;

  @ApiModelPropertyOptional()
  feeling?: number;
}